"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.LoopsClient = void 0;
class LoopsClient {
    constructor(apiKey, baseUrl = 'https://app.loops.so/api/v1') {
        this.apiKey = apiKey;
        this.baseUrl = baseUrl;
    }
    getHeaders() {
        const headers = new Headers();
        headers.append('Content-Type', 'application/json');
        headers.append('Authorization', `Bearer ${this.apiKey}`);
        return headers;
    }
    addContact(contact) {
        return __awaiter(this, void 0, void 0, function* () {
            const response = yield fetch(`${this.baseUrl}/contacts/create`, {
                method: 'POST',
                headers: this.getHeaders(),
                body: JSON.stringify(contact),
            });
            return response.json();
        });
    }
    updateContact(contact) {
        return __awaiter(this, void 0, void 0, function* () {
            const response = yield fetch(`${this.baseUrl}/contacts/update`, {
                method: 'PUT',
                headers: this.getHeaders(),
                body: JSON.stringify(contact),
            });
            return response.json();
        });
    }
    findContact(email) {
        return __awaiter(this, void 0, void 0, function* () {
            const response = yield fetch(`${this.baseUrl}/contacts/find?email=${encodeURIComponent(email)}`, {
                method: 'GET',
                headers: this.getHeaders(),
            });
            return response.json();
        });
    }
    deleteContactByEmail(email) {
        return __awaiter(this, void 0, void 0, function* () {
            const response = yield fetch(`${this.baseUrl}/contacts/delete`, {
                method: 'DELETE',
                headers: this.getHeaders(),
                body: JSON.stringify({ email }),
            });
            return response.json();
        });
    }
    deleteContactById(userId) {
        return __awaiter(this, void 0, void 0, function* () {
            const response = yield fetch(`${this.baseUrl}/contacts/delete`, {
                method: 'DELETE',
                headers: this.getHeaders(),
                body: JSON.stringify({ userId }),
            });
            return response.json();
        });
    }
    sendEvent(eventName, contact) {
        return __awaiter(this, void 0, void 0, function* () {
            const event = Object.assign(Object.assign({}, contact), { eventName });
            const response = yield fetch(`${this.baseUrl}/events/send`, {
                method: 'POST',
                headers: this.getHeaders(),
                body: JSON.stringify(event),
            });
            return response.json();
        });
    }
    sendTransactionalEmail(email, transactionalId, dataVariables) {
        return __awaiter(this, void 0, void 0, function* () {
            const input = {
                transactionalId,
                email,
                dataVariables,
            };
            const response = yield fetch(`${this.baseUrl}/transactional`, {
                method: 'POST',
                headers: this.getHeaders(),
                body: JSON.stringify(input),
            });
            return response.json();
        });
    }
}
exports.LoopsClient = LoopsClient;
